summaryrefslogtreecommitdiff
path: root/chromium/media/base/decoder.h
diff options
context:
space:
mode:
Diffstat (limited to 'chromium/media/base/decoder.h')
-rw-r--r--chromium/media/base/decoder.h17
1 files changed, 9 insertions, 8 deletions
diff --git a/chromium/media/base/decoder.h b/chromium/media/base/decoder.h
index b0705fe9c6c..f4370b12226 100644
--- a/chromium/media/base/decoder.h
+++ b/chromium/media/base/decoder.h
@@ -16,16 +16,17 @@ namespace media {
// List of known AudioDecoder implementations; recorded to UKM, always add new
// values to the end and do not reorder or delete values from this list.
enum class AudioDecoderType : int {
- kUnknown = 0, // Decoder name string is not recognized or n/a.
- kFFmpeg = 1, // FFmpegAudioDecoder
- kMojo = 2, // MojoAudioDecoder
- kDecrypting = 3, // DecryptingAudioDecoder
- kMediaCodec = 4, // MediaCodecAudioDecoder (Android)
- kBroker = 5, // AudioDecoderBroker
- kTesting = 6, // Never send this to UKM, for tests only.
+ kUnknown = 0, // Decoder name string is not recognized or n/a.
+ kFFmpeg = 1, // FFmpegAudioDecoder
+ kMojo = 2, // MojoAudioDecoder
+ kDecrypting = 3, // DecryptingAudioDecoder
+ kMediaCodec = 4, // MediaCodecAudioDecoder (Android)
+ kBroker = 5, // AudioDecoderBroker
+ kTesting = 6, // Never send this to UKM, for tests only.
+ kAudioToolbox = 7, // AudioToolbox (macOS)
// Keep this at the end and equal to the last entry.
- kMaxValue = kTesting,
+ kMaxValue = kAudioToolbox,
};
// List of known VideoDecoder implementations; recorded to UKM, always add new